@@ -37,6 +37,11 @@ DEFAULT_TENANT_NAME = 'tenant_name'
 DEFAULT_AUTH_URL = 'http://127.0.0.1:5000/v2.0/'
 
 
+# Make a fake shell object, a helping wrapper to call it
+def shell(cmd):
+    openstack_shell.OpenStackIdentityShell().main(cmd.split())
+
+
 class NoExitArgumentParser(argparse.ArgumentParser):
     def error(self, message):
         raise exceptions.CommandError(message)
@@ -68,12 +73,6 @@ class ShellTest(utils.TestCase):
             self.useFixture(fixtures.EnvironmentVariable(var,
                             self.FAKE_ENV[var]))
 
-        # Make a fake shell object, a helping wrapper to call it, and a quick
-        # way of asserting that certain API calls were made.
-        global shell, _shell, assert_called, assert_called_anytime
-        _shell = openstack_shell.OpenStackIdentityShell()
-        shell = lambda cmd: _shell.main(cmd.split())
-
     def test_help_unknown_command(self):
         self.assertRaises(exceptions.CommandError, shell, 'help %s'
                           % uuid.uuid4().hex)
@@ -235,7 +234,7 @@ class ShellTest(utils.TestCase):
             # Old_style options
             # Test case with one --tenant_id args present: ec2 creds
             shell('user-create --name=FOO '
-                  '--pass=secrete --tenant_id=barrr --enabled=true')
+                  '--pass=secret --tenant_id=barrr --enabled=true')
             assert do_uc_mock.called
             ((a, b), c) = do_uc_mock.call_args
             actual = (b.os_auth_url, b.os_password, b.os_tenant_id,
@@ -245,13 +244,13 @@ class ShellTest(utils.TestCase):
                       DEFAULT_TENANT_NAME, DEFAULT_USERNAME, '')
             self.assertTrue(all([x == y for x, y in zip(actual, expect)]))
             actual = (b.tenant_id, b.name, b.passwd, b.enabled)
-            expect = ('barrr', 'FOO', 'secrete', 'true')
+            expect = ('barrr', 'FOO', 'secret', 'true')
             self.assertTrue(all([x == y for x, y in zip(actual, expect)]))
 
             # New-style options
             # Test case with one --tenant args present: ec2 creds
             shell('user-create --name=foo '
-                  '--pass=secrete --tenant=BARRR --enabled=true')
+                  '--pass=secret --tenant=BARRR --enabled=true')
             assert do_uc_mock.called
             ((a, b), c) = do_uc_mock.call_args
             actual = (b.os_auth_url, b.os_password, b.os_tenant_id,
@@ -261,13 +260,13 @@ class ShellTest(utils.TestCase):
                       DEFAULT_TENANT_NAME, DEFAULT_USERNAME, '')
             self.assertTrue(all([x == y for x, y in zip(actual, expect)]))
             actual = (b.tenant, b.name, b.passwd, b.enabled)
-            expect = ('BARRR', 'foo', 'secrete', 'true')
+            expect = ('BARRR', 'foo', 'secret', 'true')
             self.assertTrue(all([x == y for x, y in zip(actual, expect)]))
 
             # New-style options
             # Test case with one --tenant-id args present: ec2 creds
             shell('user-create --name=foo '
-                  '--pass=secrete --tenant-id=BARRR --enabled=true')
+                  '--pass=secret --tenant-id=BARRR --enabled=true')
             assert do_uc_mock.called
             ((a, b), c) = do_uc_mock.call_args
             actual = (b.os_auth_url, b.os_password, b.os_tenant_id,
@@ -277,13 +276,13 @@ class ShellTest(utils.TestCase):
                       DEFAULT_TENANT_NAME, DEFAULT_USERNAME, '')
             self.assertTrue(all([x == y for x, y in zip(actual, expect)]))
             actual = (b.tenant, b.name, b.passwd, b.enabled)
-            expect = ('BARRR', 'foo', 'secrete', 'true')
+            expect = ('BARRR', 'foo', 'secret', 'true')
             self.assertTrue(all([x == y for x, y in zip(actual, expect)]))
 
             # Old_style options
             # Test case with --os_tenant_id and --tenant_id args present
             shell('--os_tenant_id=os-tenant user-create --name=FOO '
-                  '--pass=secrete --tenant_id=barrr --enabled=true')
+                  '--pass=secret --tenant_id=barrr --enabled=true')
             assert do_uc_mock.called
             ((a, b), c) = do_uc_mock.call_args
             actual = (b.os_auth_url, b.os_password, b.os_tenant_id,
@@ -293,13 +292,13 @@ class ShellTest(utils.TestCase):
                       DEFAULT_TENANT_NAME, DEFAULT_USERNAME, '')
             self.assertTrue(all([x == y for x, y in zip(actual, expect)]))
             actual = (b.tenant_id, b.name, b.passwd, b.enabled)
-            expect = ('barrr', 'FOO', 'secrete', 'true')
+            expect = ('barrr', 'FOO', 'secret', 'true')
             self.assertTrue(all([x == y for x, y in zip(actual, expect)]))
 
             # New-style options
             # Test case with --os-tenant-id and --tenant-id args present
             shell('--os-tenant-id=ostenant user-create --name=foo '
-                  '--pass=secrete --tenant-id=BARRR --enabled=true')
+                  '--pass=secret --tenant-id=BARRR --enabled=true')
             assert do_uc_mock.called
             ((a, b), c) = do_uc_mock.call_args
             actual = (b.os_auth_url, b.os_password, b.os_tenant_id,
@@ -309,7 +308,7 @@ class ShellTest(utils.TestCase):
                       DEFAULT_TENANT_NAME, DEFAULT_USERNAME, '')
             self.assertTrue(all([x == y for x, y in zip(actual, expect)]))
             actual = (b.tenant, b.name, b.passwd, b.enabled)
-            expect = ('BARRR', 'foo', 'secrete', 'true')
+            expect = ('BARRR', 'foo', 'secret', 'true')
             self.assertTrue(all([x == y for x, y in zip(actual, expect)]))
 
     def test_do_tenant_create(self):
@@ -521,3 +520,13 @@ class ShellTest(utils.TestCase):
                       'http://example.com:4321/go',
                       'http://example.com:9876/adm')
             self.assertTrue(all([x == y for x, y in zip(actual, expect)]))
+
+    def test_shell_keyboard_interrupt(self):
+        shell_mock = mock.MagicMock()
+        with mock.patch('keystoneclient.shell.OpenStackIdentityShell.main',
+                        shell_mock):
+            try:
+                shell_mock.side_effect = KeyboardInterrupt()
+                openstack_shell.main()
+            except SystemExit as ex:
+                self.assertEqual(130, ex.code)
